define(
//begin v1.x content
({
	insertTableTitle: "테이블 삽입",
	modifyTableTitle: "테이블 수정",
	rows: "행:",
	columns: "열:",
	align: "맞추기:",
	cellPadding: "셀 채우기:",
	cellSpacing: "셀 간격:",
	tableWidth: "테이블 너비:",
	backgroundColor: "배경색:",
	borderColor: "테두리 색:",
	borderThickness: "테두리 굵기",
	percent: "백분율",
	pixels: "픽셀",
	"default": "기본값",
	left: "왼쪽",
	center: "가운데",
	right: "오른쪽",
	buttonSet: "설정", // translated elsewhere?
	buttonInsert: "삽입",
	buttonCancel: "취소",

	selectTableLabel: "테이블 선택",
	insertTableRowBeforeLabel: "사전 행 추가",
	insertTableRowAfterLabel: "사후 행 추가",
	insertTableColumnBeforeLabel: "사전 열 추가",
	insertTableColumnAfterLabel: "사후 열 추가",
	deleteTableRowLabel: "행 삭제",
	deleteTableColumnLabel: "열 삭제"
})
//end v1.x content
);
